@@ -10,6 +10,14 @@
 #' (such as prior and updating functions).
 #' @return Object of class \code{ssm_ulg}, \code{ssm_mlg}, \code{ssm_ung} or \code{ssm_mng}.
 #' @export
+#' @examples
+#' library("KFAS")
+#' model_KFAS <- SSModel(Nile ~
+#'   SSMtrend(1, Q = 2, P1 = 1e4), H = 2)
+#' model_bssm <- as_bssm(model_KFAS)  
+#' logLik(model_KFAS)
+#' logLik(model_bssm)
+#' 
 as_bssm <- function(model, kappa = 100, ...) {
   
   if (!requireNamespace("KFAS", quietly = TRUE)) {
@@ -77,10 +85,6 @@ as_bssm <- function(model, kappa = 100, ...) {
       u <- model$u
       for(i in 1:attr(model, "p")) {
         switch(model$distribution[i],
-          poisson = {
-            phi[i] <- 1
-            u[,i] <- model$u[,i]
-          },
           poisson = {
             phi[i] <- 1
             u[,i] <- model$u[,i]
