@@ -4,10 +4,12 @@
 #' based on either bootstrap particle filter [1], \eqn{\psi}-auxiliary particle filter (\eqn{\psi}-APF) [2], 
 #' or extended Kalman particle filter [3] (or its iterated version [4]). 
 #' The smoothing phase is based on the filter-smoother algorithm by [5].
+#' 
+#' See one of the vignettes for \eqn{\psi}-APF in case of nonlinear models.
 #'
 #' @importFrom stats cov
 #' @param model Model.
-#' @param nsim Number of samples.
+#' @param particles Number of samples for particle filter.
 #' @param method Choice of particle filter algorithm. 
 #' For Gaussian and non-Gaussian models with linear dynamics,
 #' options are \code{"bsf"} (bootstrap particle filter, default for non-linear models) 
@@ -35,7 +37,7 @@
 #' Journal of Computational and Graphical Statistics, 5, 1–25.
 #' @export
 #' @rdname particle_smoother
-particle_smoother <- function(model, nsim, ...) {
+particle_smoother <- function(model, particles, ...) {
   UseMethod("particle_smoother", model)
 }
 
@@ -47,17 +49,25 @@ particle_smoother <- function(model, nsim, ...) {
 #' x <- cumsum(rnorm(100))
 #' y <- rnorm(100, x)
 #' model <- ssm_ulg(y, Z = 1, T = 1, R = 1, H = 1, P1 = 1)
-#' system.time(out <- particle_smoother(model, nsim = 1000))
+#' system.time(out <- particle_smoother(model, particles = 1000))
 #' # same with simulation smoother:
-#' system.time(out2 <- sim_smoother(model, nsim = 1000, use_antithetic = TRUE))
+#' system.time(out2 <- sim_smoother(model, particles = 1000, use_antithetic = TRUE))
 #' ts.plot(out$alphahat, rowMeans(out2), col = 1:2)
 #' 
-particle_smoother.gaussian <- function(model, nsim,  method = "psi",
+particle_smoother.gaussian <- function(model, particles,  method = "psi",
   seed = sample(.Machine$integer.max, size = 1), ...) {
   
+  if(missing(particles)) {
+    nsim <- eval(match.call(expand.dots = TRUE)$nsim)
+    if (!is.null(nsim)) {
+      warning("Argument `nsim` is deprecated. Use argument `particles` instead.")
+      particles <- nsim
+    }
+  }
+  
   if(method == "psi") {
     out <- list()
-    out$alpha <- gaussian_psi_smoother(model, nsim, seed, model_type(model))
+    out$alpha <- gaussian_psi_smoother(model, particles, seed, model_type(model))
     out$alphahat <- t(apply(out$alpha, 1:2, mean))
     if(ncol(out$alphahat) == 1L) {
       out$Vt <- array(apply(out$alpha[1, , ], 1, var), c(1, 1, nrow(out$alphahat)))
@@ -68,7 +78,7 @@ particle_smoother.gaussian <- function(model, nsim,  method = "psi",
       }
     }
   } else {
-    out <- bsf_smoother(model, nsim, seed, TRUE, model_type(model))
+    out <- bsf_smoother(model, particles, seed, TRUE, model_type(model))
     
   }
   colnames(out$alphahat) <- colnames(out$Vt) <-
@@ -83,11 +93,19 @@ particle_smoother.gaussian <- function(model, nsim,  method = "psi",
 #' @rdname particle_smoother
 #' @method particle_smoother nongaussian
 #' @export
-particle_smoother.nongaussian <- function(model, nsim, 
+particle_smoother.nongaussian <- function(model, particles, 
   method = "psi", 
   seed = sample(.Machine$integer.max, size = 1), 
   max_iter = 100, conv_tol = 1e-8, ...) {
   
+  if(missing(particles)) {
+    nsim <- eval(match.call(expand.dots = TRUE)$nsim)
+    if (!is.null(nsim)) {
+      warning("Argument `nsim` is deprecated. Use argument `particles` instead.")
+      particles <- nsim
+    }
+  }
+  
   method <- match.arg(method, c("bsf", "psi"))
   
   model$max_iter <- max_iter
@@ -97,9 +115,9 @@ particle_smoother.nongaussian <- function(model, nsim,
     duplicates.ok = TRUE) - 1
   
   if(method == "psi") {
-    out <- psi_smoother(model, nsim, seed, model_type(model))
+    out <- psi_smoother(model, particles, seed, model_type(model))
   } else {
-    out <- bsf_smoother(model, nsim, seed, FALSE, model_type(model))
+    out <- bsf_smoother(model, particles, seed, FALSE, model_type(model))
   }
   colnames(out$alphahat) <- colnames(out$Vt) <-
     colnames(out$Vt) <- names(model$a1)
@@ -114,11 +132,19 @@ particle_smoother.nongaussian <- function(model, nsim,
 #' @rdname particle_smoother
 #' @method particle_smoother ssm_nlg
 #' @export
-particle_smoother.ssm_nlg <- function(model, nsim, 
+particle_smoother.ssm_nlg <- function(model, particles, 
   method = "bsf", 
   seed = sample(.Machine$integer.max, size = 1),
   max_iter = 100, conv_tol = 1e-8, iekf_iter = 0, ...) {
   
+  if(missing(particles)) {
+    nsim <- eval(match.call(expand.dots = TRUE)$nsim)
+    if (!is.null(nsim)) {
+      warning("Argument `nsim` is deprecated. Use argument `particles` instead.")
+      particles <- nsim
+    }
+  }
+  
   method <- match.arg(method, c("bsf", "psi", "ekf"))
   
   out <- switch(method,
@@ -126,18 +152,18 @@ particle_smoother.ssm_nlg <- function(model, nsim,
       model$R, model$Z_gn, model$T_gn, model$a1, model$P1, 
       model$theta, model$log_prior_pdf, model$known_params, 
       model$known_tv_params, model$n_states, model$n_etas, 
-      as.integer(model$time_varying), nsim, seed,
+      as.integer(model$time_varying), particles, seed,
       max_iter, conv_tol, iekf_iter, default_update_fn, default_prior_fn),
     bsf = bsf_smoother_nlg(t(model$y), model$Z, model$H, model$T, 
       model$R, model$Z_gn, model$T_gn, model$a1, model$P1, 
       model$theta, model$log_prior_pdf, model$known_params, 
       model$known_tv_params, model$n_states, model$n_etas, 
-      as.integer(model$time_varying), nsim, seed, default_update_fn, default_prior_fn),
+      as.integer(model$time_varying), particles, seed, default_update_fn, default_prior_fn),
     ekf = ekpf_smoother(t(model$y), model$Z, model$H, model$T, 
       model$R, model$Z_gn, model$T_gn, model$a1, model$P1, 
       model$theta, model$log_prior_pdf, model$known_params, 
       model$known_tv_params, model$n_states, model$n_etas, 
-      as.integer(model$time_varying), nsim, 
+      as.integer(model$time_varying), particles, 
       seed, default_update_fn, default_prior_fn)
   )
   colnames(out$alphahat) <- colnames(out$Vt) <-
@@ -155,14 +181,23 @@ particle_smoother.ssm_nlg <- function(model, nsim,
 #' @method particle_smoother ssm_sde
 #' @param L Integer defining the discretization level.
 #' @export
-particle_smoother.ssm_sde <- function(model, nsim, L, 
+particle_smoother.ssm_sde <- function(model, particles, L, 
   seed = sample(.Machine$integer.max, size = 1), ...) {
   
   if(L < 1) stop("Discretization level L must be larger than 0.")
+  
+  if(missing(particles)) {
+    nsim <- eval(match.call(expand.dots = TRUE)$nsim)
+    if (!is.null(nsim)) {
+      warning("Argument `nsim` is deprecated. Use argument `particles` instead.")
+      particles <- nsim
+    }
+  }
+  
   out <-  bsf_smoother_sde(model$y, model$x0, model$positive, 
     model$drift, model$diffusion, model$ddiffusion, 
     model$prior_pdf, model$obs_pdf, model$theta, 
-    nsim, round(L), seed)
+    particles, round(L), seed)
   
   colnames(out$alphahat) <- colnames(out$Vt) <-
     colnames(out$Vt) <- model$state_names
