@@ -1,7 +1,8 @@
 #' Bayesian Inference of State Space Models
 #'
 #' Adaptive Markov chain Monte Carlo simulation of state space models using
-#' Robust Adaptive Metropolis algorithm by Vihola (2012). See specific methods for various model types for details.
+#' Robust Adaptive Metropolis algorithm by Vihola (2012). 
+#' See specific methods for various model types for details.
 #'
 #' @importFrom stats tsp
 #' @param model State space model model of \code{bssm} package.
@@ -43,7 +44,7 @@ run_mcmc <- function(model, iter, ...) {
 #' distribution is \eqn{SS'}. Note that for some parameters 
 #' (currently the standard deviation and dispersion parameters of bsm_lg models) the sampling
 #' is done for transformed parameters with internal_theta = log(theta).
-#' @param end_adaptive_phase If \code{TRUE} (default), S is held fixed after the burnin period.
+#' @param end_adaptive_phase If \code{TRUE}, S is held fixed after the burnin period. Default is \code{FALSE}.
 #' @param threads Number of threads for state simulation.
 #' @param seed Seed for the random number generator.
 #' @param ... Ignored.
@@ -51,9 +52,29 @@ run_mcmc <- function(model, iter, ...) {
 #' Vihola, M, Helske, J, Franks, J. Importance sampling type estimators based on approximate marginal Markov chain Monte Carlo. 
 #' Scand J Statist. 2020; 1– 38. https://doi.org/10.1111/sjos.12492
 #' @export
+#' @examples 
+#' model <- ar1_lg(LakeHuron, rho = uniform(0.5,-1,1), 
+#'   sigma = halfnormal(1, 10), mu = normal(500, 500, 500), 
+#'   sd_y = halfnormal(1, 10))
+#' 
+#' mcmc_results <- run_mcmc(model, iter = 2e4)
+#' summary(mcmc_results, return_se = TRUE)
+#' 
+#' require("dplyr")
+#' sumr <- as.data.frame(mcmc_results, variable = "states") %>%
+#'   group_by(time) %>%
+#'   summarise(mean = mean(value), 
+#'     lwr = quantile(value, 0.025), 
+#'     upr = quantile(value, 0.975))
+#' require("ggplot2")
+#' sumr %>% ggplot(aes(time, mean)) + 
+#'   geom_ribbon(aes(ymin = lwr, ymax = upr),alpha=0.25) + 
+#'   geom_line() + theme_bw() +
+#'   geom_point(data = data.frame(mean = LakeHuron, time = time(LakeHuron)),
+#'     col = 2)
 run_mcmc.gaussian <- function(model, iter, output_type = "full",
   burnin = floor(iter / 2), thin = 1, gamma = 2/3,
-  target_acceptance = 0.234, S, end_adaptive_phase = TRUE, threads = 1,
+  target_acceptance = 0.234, S, end_adaptive_phase = FALSE, threads = 1,
   seed = sample(.Machine$integer.max, size = 1), ...) {
   
   
@@ -121,7 +142,7 @@ run_mcmc.gaussian <- function(model, iter, output_type = "full",
 #' @export
 #' @param model Model model.
 #' @param iter Number of MCMC iterations.
-#' @param nsim Number of state samples per MCMC iteration.
+#' @param particles Number of state samples per MCMC iteration.
 #' Ignored if \code{mcmc_type} is \code{"approx"}.
 #' @param output_type Either \code{"full"} 
 #' (default, returns posterior samples of states alpha and hyperparameters theta), 
@@ -130,11 +151,11 @@ run_mcmc.gaussian <- function(model, iter, output_type = "full",
 #' and posterior samples of theta).
 #' @param mcmc_type What MCMC algorithm to use? Possible choices are
 #' \code{"pm"} for pseudo-marginal MCMC,
-#' \code{"da"} for delayed acceptance version of PMCMC (default), 
+#' \code{"da"} for delayed acceptance version of PMCMC , 
 #' \code{"approx"} for approximate inference based on the Gaussian approximation of the model,
 #' or one of the three importance sampling type weighting schemes:
 #' \code{"is3"} for simple importance sampling (weight is computed for each MCMC iteration independently),
-#' \code{"is2"} for jump chain importance sampling type weighting, or
+#' \code{"is2"} for jump chain importance sampling type weighting (default), or
 #' \code{"is1"} for importance sampling type weighting where the number of particles used for
 #' weight computations is proportional to the length of the jump chain block.
 #' @param sampling_method If \code{"psi"}, \eqn{\psi}-APF is used for state sampling
@@ -150,15 +171,15 @@ run_mcmc.gaussian <- function(model, iter, output_type = "full",
 #' of the summary statistics in case of pseudo-marginal methods.
 #' @param gamma Tuning parameter for the adaptation of RAM algorithm. Must be
 #' between 0 and 1 (not checked).
-#' @param target_acceptance Target acceptance ratio for RAM. Defaults to 0.234.
+#' @param target_acceptance Target acceptance ratio for RAM. Defaults to 0.234. 
 #' @param S Initial value for the lower triangular matrix of RAM
 #' algorithm, so that the covariance matrix of the Gaussian proposal
 #' distribution is \eqn{SS'}. Note that for some parameters 
 #' (currently the standard deviation and dispersion parameters of bsm_ng models) the sampling
 #' is done for transformed parameters with internal_theta = log(theta).
-#' @param end_adaptive_phase If \code{TRUE} (default), S is held fixed after the burnin period.
+#' @param end_adaptive_phase If \code{TRUE}, S is held fixed after the burnin period. Default is \code{FALSE}.
 #' @param local_approx If \code{TRUE} (default), Gaussian approximation needed for
-#' importance sampling is performed at each iteration. If false, approximation is updated only
+#' importance sampling is performed at each iteration. If \code{FALSE}, approximation is updated only
 #' once at the start of the MCMC.
 #' @param threads Number of threads for state simulation.
 #' @param seed Seed for the random number generator.
@@ -175,7 +196,9 @@ run_mcmc.gaussian <- function(model, iter, output_type = "full",
 #'   sd_level = halfnormal(0.01, 1), 
 #'   sd_slope = halfnormal(0.01, 0.1), 
 #'   P1 = diag(c(10, 0.1)), distribution = "poisson")
-#' mcmc_is <- run_mcmc(poisson_model, iter = 1000, nsim = 10, 
+#'   
+#' # Note small number of iterations for CRAN checks
+#' mcmc_is <- run_mcmc(poisson_model, iter = 1000, particles = 10, 
 #'   mcmc_type = "da")
 #' summary(mcmc_is, what = "theta", return_se = TRUE)
 #' 
@@ -199,8 +222,9 @@ run_mcmc.gaussian <- function(model, iter, output_type = "full",
 #'   distribution = "negative binomial")
 #' 
 #' # run IS-MCMC
-#' fit <- run_mcmc(model, iter = 10000,
-#'   nsim = 10, mcmc_type = "is2", seed = 1)
+#' # Note small number of iterations for CRAN checks
+#' fit <- run_mcmc(model, iter = 5000,
+#'   particles = 10, mcmc_type = "is2", seed = 1)
 #'
 #' # extract states   
 #' d_states <- as.data.frame(fit, variable = "states", time = 1:n)
@@ -227,21 +251,64 @@ run_mcmc.gaussian <- function(model, iter, output_type = "full",
 #'   theme(legend.title = element_blank()) + 
 #'   xlab("Time") + ylab("Level")
 #' 
+#' # Bivariate Poisson model:
 #' 
-run_mcmc.nongaussian <- function(model, iter, nsim, output_type = "full",
-  mcmc_type = "da", sampling_method = "psi", burnin = floor(iter/2),
-  thin = 1, gamma = 2/3, target_acceptance = 0.234, S, end_adaptive_phase = TRUE,
+#' set.seed(1)
+#' x <- cumsum(c(3, rnorm(19, sd = 0.5)))
+#' y <- cbind(
+#'   rpois(20, exp(x)), 
+#'   rpois(20, exp(x)))
+#' 
+#' prior_fn <- function(theta) {
+#'   # half-normal prior using transformation
+#'   dnorm(exp(theta), 0, 1, log = TRUE) + theta # plus jacobian term
+#' }
+#' 
+#' update_fn <- function(theta) {
+#'   list(R = array(exp(theta), c(1, 1, 1)))
+#' }
+#' 
+#' model <- ssm_mng(y = y, Z = matrix(1,2,1), T = 1, 
+#'   R = 0.1, P1 = 1, distribution = "poisson",
+#'   init_theta = log(0.1), 
+#'   prior_fn = prior_fn, update_fn = update_fn)
+#'   
+#' # Note small number of iterations for CRAN checks
+#' out <- run_mcmc(model, iter = 5000, mcmc_type = "approx")
+#' 
+#' sumr <- as.data.frame(out, variable = "states") %>% 
+#'   group_by(time) %>% mutate(value = exp(value)) %>%
+#'   summarise(mean = mean(value), 
+#'     ymin = quantile(value, 0.05), ymax = quantile(value, 0.95))
+#' ggplot(sumr, aes(time, mean)) + 
+#' geom_ribbon(aes(ymin = ymin, ymax = ymax),alpha = 0.25) + 
+#' geom_line() + 
+#' geom_line(data = data.frame(mean = y[, 1], time = 1:20), colour = "tomato") + 
+#' geom_line(data = data.frame(mean = y[, 2], time = 1:20), colour = "tomato") +
+#' theme_bw()
+#' 
+run_mcmc.nongaussian <- function(model, iter, particles, output_type = "full",
+  mcmc_type = "is2", sampling_method = "psi", burnin = floor(iter/2),
+  thin = 1, gamma = 2/3, target_acceptance = 0.234, S, end_adaptive_phase = FALSE,
   local_approx  = TRUE, threads = 1,
   seed = sample(.Machine$integer.max, size = 1), max_iter = 100, conv_tol = 1e-8, ...) {
   
+  if(missing(particles)) {
+    nsim <- eval(match.call(expand.dots = TRUE)$nsim)
+    if (!is.null(nsim)) {
+      warning("Argument `nsim` is deprecated. Use argument `particles` instead.")
+      particles <- nsim
+    }
+  }
+  
   if(length(model$theta) == 0) stop("No unknown parameters ('model$theta' has length of zero).")
   a <- proc.time()
   check_target(target_acceptance)
   
   output_type <- pmatch(output_type, c("full", "summary", "theta"))
   mcmc_type <- match.arg(mcmc_type, c("pm", "da", paste0("is", 1:3), "approx"))
-  if (mcmc_type == "approx") nsim <- 0
-  if (nsim < 2 && mcmc_type != "approx") 
+  if (mcmc_type == "approx") particles <- 0
+  if (particles < 2 && mcmc_type != "approx") 
     stop("Number of state samples less than 2, use 'mcmc_type' 'approx' instead.")
   
   sampling_method <- pmatch(match.arg(sampling_method, c("psi", "bsf", "spdk")), 
@@ -270,13 +337,13 @@ run_mcmc.nongaussian <- function(model, iter, nsim, output_type = "full",
   switch(mcmc_type,
     "da" = {
       out <- nongaussian_da_mcmc(model, 
-        output_type, nsim, iter, burnin, thin, gamma, target_acceptance, S,
+        output_type, particles, iter, burnin, thin, gamma, target_acceptance, S,
         seed, end_adaptive_phase, threads,
         sampling_method, model_type(model))
     },
     "pm" = {
       out <- nongaussian_pm_mcmc(model, output_type,
-        nsim, iter, burnin, thin, gamma, target_acceptance, S,
+        particles, iter, burnin, thin, gamma, target_acceptance, S,
         seed, end_adaptive_phase, threads, 
         sampling_method, model_type(model))
     },
@@ -284,14 +351,14 @@ run_mcmc.nongaussian <- function(model, iter, nsim, output_type = "full",
     "is2" =,
     "is3" = {
       out <- nongaussian_is_mcmc(model, output_type,
-        nsim, iter, burnin, thin, gamma, target_acceptance, S,
+        particles, iter, burnin, thin, gamma, target_acceptance, S,
         seed, end_adaptive_phase, threads, 
         sampling_method,
         pmatch(mcmc_type, paste0("is", 1:3)), model_type(model), FALSE)
     },
     "approx" = {
       out <- nongaussian_is_mcmc(model, output_type,
-        nsim, iter, burnin, thin, gamma, target_acceptance, S,
+        particles, iter, burnin, thin, gamma, target_acceptance, S,
         seed, end_adaptive_phase, threads, 
         sampling_method, 2, model_type(model), TRUE)
     })
@@ -331,7 +398,7 @@ run_mcmc.nongaussian <- function(model, iter, nsim, output_type = "full",
 #' @method run_mcmc ssm_nlg
 #' @param model Model model.
 #' @param iter Number of MCMC iterations.
-#' @param nsim Number of state samples per MCMC iteration. 
+#' @param particles Number of state samples per MCMC iteration. 
 #' Ignored if \code{mcmc_type} is \code{"approx"} or \code{"ekf"}.
 #' @param output_type Either \code{"full"} 
 #' (default, returns posterior samples of states alpha and hyperparameters theta), 
@@ -340,12 +407,12 @@ run_mcmc.nongaussian <- function(model, iter, nsim, output_type = "full",
 #' and posterior samples of theta). 
 #' @param mcmc_type What MCMC algorithm to use? Possible choices are
 #' \code{"pm"} for pseudo-marginal MCMC,
-#' \code{"da"} for delayed acceptance version of PMCMC (default), 
+#' \code{"da"} for delayed acceptance version of pseudo-marginal MCMC, 
 #' \code{"approx"} for approximate inference based on the Gaussian approximation of the model,
 #' \code{"ekf"} for approximate inference using extended Kalman filter, 
 #' or one of the three importance sampling type weighting schemes:
 #' \code{"is3"} for simple importance sampling (weight is computed for each MCMC iteration independently),
-#' \code{"is2"} for jump chain importance sampling type weighting, or
+#' \code{"is2"} for jump chain importance sampling type weighting (default), or
 #' \code{"is1"} for importance sampling type weighting where the number of particles used for
 #' weight computations is proportional to the length of the jump chain block.
 #' @param sampling_method If \code{"bsf"} (default), bootstrap filter is used for state sampling. 
@@ -366,7 +433,7 @@ run_mcmc.nongaussian <- function(model, iter, nsim, output_type = "full",
 #' distribution is \eqn{SS'}. Note that for some parameters 
 #' (currently the standard deviation and dispersion parameters of bsm_ng models) the sampling
 #' is done for transformed parameters with internal_theta = log(theta).
-#' @param end_adaptive_phase If \code{TRUE} (default), S is held fixed after the burnin period.
+#' @param end_adaptive_phase If \code{TRUE}, S is held fixed after the burnin period. Default is \code{FALSE}.
 #' @param threads Number of threads for state simulation.
 #' @param seed Seed for the random number generator.
 #' @param max_iter Maximum number of iterations used in Gaussian approximation.
@@ -378,20 +445,28 @@ run_mcmc.nongaussian <- function(model, iter, nsim, output_type = "full",
 #' @references 
 #' Vihola, M, Helske, J, Franks, J. Importance sampling type estimators based on approximate marginal Markov chain Monte Carlo. 
 #' Scand J Statist. 2020; 1– 38. https://doi.org/10.1111/sjos.12492
-run_mcmc.ssm_nlg <-  function(model, iter, nsim, output_type = "full",
-  mcmc_type = "da", sampling_method = "bsf",
+run_mcmc.ssm_nlg <-  function(model, iter, particles, output_type = "full",
+  mcmc_type = "is2", sampling_method = "bsf",
   burnin = floor(iter/2), thin = 1,
-  gamma = 2/3, target_acceptance = 0.234, S, end_adaptive_phase = TRUE,
+  gamma = 2/3, target_acceptance = 0.234, S, end_adaptive_phase = FALSE,
   threads = 1, seed = sample(.Machine$integer.max, size = 1), max_iter = 100,
   conv_tol = 1e-8, iekf_iter = 0, ...) {
   
+  if(missing(particles)) {
+    nsim <- eval(match.call(expand.dots = TRUE)$nsim)
+    if (!is.null(nsim)) {
+      warning("Argument `nsim` is deprecated. Use argument `particles` instead.")
+      particles <- nsim
+    }
+  }
+  
   if(length(model$theta) == 0) stop("No unknown parameters ('model$theta' has length of zero).")
   a <- proc.time()
   check_target(target_acceptance)
   
   output_type <- pmatch(output_type, c("full", "summary", "theta"))
   mcmc_type <- match.arg(mcmc_type, c("pm", "da", paste0("is", 1:3), "ekf", "approx"))
-  if(mcmc_type %in% c("ekf", "approx")) nsim <- 0
+  if(mcmc_type %in% c("ekf", "approx")) particles <- 0
   sampling_method <- pmatch(match.arg(sampling_method, c("psi", "bsf", "ekf")), 
     c("psi", "bsf", NA, "ekf"))
   
@@ -399,7 +474,7 @@ run_mcmc.ssm_nlg <-  function(model, iter, nsim, output_type = "full",
     S <- diag(0.1 * pmax(0.1, abs(model$theta)), length(model$theta))
   }
   
-  if (nsim < 2 && !(mcmc_type %in% c("ekf", "approx")))
+  if (particles < 2 && !(mcmc_type %in% c("ekf", "approx")))
      stop("Number of state samples less than 2, use 'mcmc_type' 'approx' or 'ekf' instead.")
  
   
@@ -410,7 +485,7 @@ run_mcmc.ssm_nlg <-  function(model, iter, nsim, output_type = "full",
         model$theta, model$log_prior_pdf, model$known_params,
         model$known_tv_params, as.integer(model$time_varying),
         model$n_states, model$n_etas, seed,
-        nsim, iter, burnin, thin, gamma, target_acceptance, S,
+        particles, iter, burnin, thin, gamma, target_acceptance, S,
         end_adaptive_phase, threads, max_iter, conv_tol,
         sampling_method,iekf_iter, output_type, 
         default_update_fn, default_prior_fn)
@@ -421,7 +496,7 @@ run_mcmc.ssm_nlg <-  function(model, iter, nsim, output_type = "full",
         model$theta, model$log_prior_pdf, model$known_params,
         model$known_tv_params, as.integer(model$time_varying),
         model$n_states, model$n_etas, seed,
-        nsim, iter, burnin, thin, gamma, target_acceptance, S,
+        particles, iter, burnin, thin, gamma, target_acceptance, S,
         end_adaptive_phase, threads, max_iter, conv_tol,
         sampling_method,iekf_iter, output_type, 
         default_update_fn, default_prior_fn)
@@ -436,7 +511,7 @@ run_mcmc.ssm_nlg <-  function(model, iter, nsim, output_type = "full",
         model$theta, model$log_prior_pdf, model$known_params,
         model$known_tv_params, as.integer(model$time_varying),
         model$n_states, model$n_etas, seed,
-        nsim, iter, burnin, thin, gamma, target_acceptance, S,
+        particles, iter, burnin, thin, gamma, target_acceptance, S,
         end_adaptive_phase, threads, pmatch(mcmc_type, paste0("is", 1:3)),
         sampling_method, max_iter, conv_tol, iekf_iter, 
         output_type, default_update_fn, 
@@ -458,7 +533,7 @@ run_mcmc.ssm_nlg <-  function(model, iter, nsim, output_type = "full",
         model$theta, model$log_prior_pdf, model$known_params,
         model$known_tv_params, as.integer(model$time_varying),
         model$n_states, model$n_etas, seed,
-        nsim, iter, burnin, thin, gamma, target_acceptance, S,
+        particles, iter, burnin, thin, gamma, target_acceptance, S,
         end_adaptive_phase, threads, 2,
         sampling_method, max_iter, conv_tol, 
         iekf_iter, output_type, default_update_fn, 
@@ -500,18 +575,18 @@ run_mcmc.ssm_nlg <-  function(model, iter, nsim, output_type = "full",
 #' @method run_mcmc ssm_sde
 #' @param model Model model.
 #' @param iter Number of MCMC iterations.
-#' @param nsim Number of state samples per MCMC iteration.
+#' @param particles Number of state samples per MCMC iteration.
 #' @param output_type Either \code{"full"} 
 #' (default, returns posterior samples of states alpha and hyperparameters theta), 
 #' \code{"theta"} (for marginal posterior of theta), 
 #' or \code{"summary"} (return the mean and variance estimates of the states 
-#' and posterior samples of theta). If \code{nsim = 0}, this is argument ignored and set to \code{"theta"}.
+#' and posterior samples of theta). If \code{particles = 0}, this is argument ignored and set to \code{"theta"}.
 #' @param mcmc_type What MCMC algorithm to use? Possible choices are
 #' \code{"pm"} for pseudo-marginal MCMC,
-#' \code{"da"} for delayed acceptance version of PMCMC (default), 
+#' \code{"da"} for delayed acceptance version of pseudo-marginal MCMC, 
 #' or one of the three importance sampling type weighting schemes:
 #' \code{"is3"} for simple importance sampling (weight is computed for each MCMC iteration independently),
-#' \code{"is2"} for jump chain importance sampling type weighting, or
+#' \code{"is2"} for jump chain importance sampling type weighting (default), or
 #' \code{"is1"} for importance sampling type weighting where the number of particles used for
 #' weight computations is proportional to the length of the jump chain block.
 #' @param burnin Length of the burn-in period which is disregarded from the
@@ -529,7 +604,7 @@ run_mcmc.ssm_nlg <-  function(model, iter, nsim, output_type = "full",
 #' distribution is \eqn{SS'}. Note that for some parameters 
 #' (currently the standard deviation and dispersion parameters of bsm_ng models) the sampling
 #' is done for transformed parameters with internal_theta = log(theta).
-#' @param end_adaptive_phase If \code{TRUE} (default), S is held fixed after the burnin period.
+#' @param end_adaptive_phase If \code{TRUE}, S is held fixed after the burnin period. Default is \code{FALSE}.
 #' @param threads Number of threads for state simulation.
 #' @param L_c,L_f Integer values defining the discretization levels for first and second stages (defined as 2^L). 
 #' For PM methods, maximum of these is used.
@@ -539,10 +614,10 @@ run_mcmc.ssm_nlg <-  function(model, iter, nsim, output_type = "full",
 #' @references 
 #' Vihola, M, Helske, J, Franks, J. Importance sampling type estimators based on approximate marginal Markov chain Monte Carlo. 
 #' Scand J Statist. 2020; 1– 38. https://doi.org/10.1111/sjos.12492
-run_mcmc.ssm_sde <-  function(model, iter, nsim, output_type = "full",
-  mcmc_type = "da", L_c, L_f,
+run_mcmc.ssm_sde <-  function(model, iter, particles, output_type = "full",
+  mcmc_type = "is2", L_c, L_f,
   burnin = floor(iter/2), thin = 1,
-  gamma = 2/3, target_acceptance = 0.234, S, end_adaptive_phase = TRUE,
+  gamma = 2/3, target_acceptance = 0.234, S, end_adaptive_phase = FALSE,
   threads = 1, seed = sample(.Machine$integer.max, size = 1), ...) {
   
   if(any(c(model$drift, model$diffusion, model$ddiffusion,
@@ -550,10 +625,18 @@ run_mcmc.ssm_sde <-  function(model, iter, nsim, output_type = "full",
     stop("NULL pointer detected, please recompile the pointer file and reconstruct the model.")
   }
   
+  if(missing(particles)) {
+    nsim <- eval(match.call(expand.dots = TRUE)$nsim)
+    if (!is.null(nsim)) {
+      warning("Argument `nsim` is deprecated. Use argument `particles` instead.")
+      particles <- nsim
+    }
+  }
+  
   if(length(model$theta) == 0) stop("No unknown parameters ('model$theta' has length of zero).")
   a <- proc.time()
   check_target(target_acceptance)
-  if(nsim <= 0) stop("nsim should be positive integer.")
+  if(particles <= 0) stop("particles should be positive integer.")
   
   output_type <- pmatch(output_type, c("full", "summary", "theta"))
   mcmc_type <- match.arg(mcmc_type, c("pm", "da", paste0("is", 1:3)))
@@ -568,7 +651,7 @@ run_mcmc.ssm_sde <-  function(model, iter, nsim, output_type = "full",
     out <- sde_da_mcmc(model$y, model$x0, model$positive,
       model$drift, model$diffusion, model$ddiffusion,
       model$prior_pdf, model$obs_pdf, model$theta,
-      nsim, L_c, L_f, seed,
+      particles, L_c, L_f, seed,
       iter, burnin, thin, gamma, target_acceptance, S,
       end_adaptive_phase, output_type)
   } else {
@@ -580,7 +663,7 @@ run_mcmc.ssm_sde <-  function(model, iter, nsim, output_type = "full",
       out <- sde_pm_mcmc(model$y, model$x0, model$positive,
         model$drift, model$diffusion, model$ddiffusion,
         model$prior_pdf, model$obs_pdf, model$theta,
-        nsim, L, seed,
+        particles, L, seed,
         iter, burnin, thin, gamma, target_acceptance, S,
         end_adaptive_phase, output_type)
     } else {
@@ -590,7 +673,7 @@ run_mcmc.ssm_sde <-  function(model, iter, nsim, output_type = "full",
       out <- sde_is_mcmc(model$y, model$x0, model$positive,
         model$drift, model$diffusion, model$ddiffusion,
         model$prior_pdf, model$obs_pdf, model$theta,
-        nsim, L_c, L_f, seed,
+        particles, L_c, L_f, seed,
         iter, burnin, thin, gamma, target_acceptance, S,
         end_adaptive_phase, pmatch(mcmc_type, paste0("is", 1:3)), 
         threads, output_type)
