@@ -1,18 +1,18 @@
-#include "nlg_ssm.h"
+#include "model_ssm_nlg.h"
 
 #include "filter_smoother.h"
 #include "summary.h"
 
 // [[Rcpp::export]]
-Rcpp::List ekpf(const arma::mat& y, SEXP Z, SEXP H, 
-  SEXP T, SEXP R, SEXP Zg, SEXP Tg, SEXP a1, SEXP P1, 
-  const arma::vec& theta, SEXP log_prior_pdf, const arma::vec& known_params, 
-  const arma::mat& known_tv_params, const unsigned int n_states, 
+Rcpp::List ekpf(const arma::mat& y, SEXP Z, SEXP H,
+  SEXP T, SEXP R, SEXP Zg, SEXP Tg, SEXP a1, SEXP P1,
+  const arma::vec& theta, SEXP log_prior_pdf, const arma::vec& known_params,
+  const arma::mat& known_tv_params, const unsigned int n_states,
   const unsigned int n_etas,  const arma::uvec& time_varying,
-  const unsigned int nsim_states, 
-  const unsigned int seed) {
-  
-  
+  const unsigned int nsim, const unsigned int seed,
+  const Rcpp::Function update_fn, const Rcpp::Function prior_fn) {
+
+
   Rcpp::XPtr<nvec_fnPtr> xpfun_Z(Z);
   Rcpp::XPtr<nmat_fnPtr> xpfun_H(H);
   Rcpp::XPtr<nvec_fnPtr> xpfun_T(T);
@@ -22,43 +22,43 @@ Rcpp::List ekpf(const arma::mat& y, SEXP Z, SEXP H,
   Rcpp::XPtr<a1_fnPtr> xpfun_a1(a1);
   Rcpp::XPtr<P1_fnPtr> xpfun_P1(P1);
   Rcpp::XPtr<prior_fnPtr> xpfun_prior(log_prior_pdf);
-  
-  nlg_ssm model(y, *xpfun_Z, *xpfun_H, *xpfun_T, *xpfun_R, *xpfun_Zg, *xpfun_Tg, 
+
+  ssm_nlg model(y, *xpfun_Z, *xpfun_H, *xpfun_T, *xpfun_R, *xpfun_Zg, *xpfun_Tg,
     *xpfun_a1, *xpfun_P1,  theta, *xpfun_prior, known_params, known_tv_params, n_states, n_etas,
-    time_varying, seed);
-  
+    time_varying, update_fn, prior_fn, seed);
+
   unsigned int m = model.m;
   unsigned n = model.n;
-  
-  arma::cube alpha(m, n, nsim_states + 1);
-  arma::mat weights(nsim_states + 1, n);
-  arma::umat indices(nsim_states, n);
-  double loglik = model.ekf_filter(nsim_states, alpha, weights, indices);
-  
-  
+
+  arma::cube alpha(m, n+1, nsim);
+  arma::mat weights(nsim, n+1);
+  arma::umat indices(nsim, n);
+  double loglik = model.ekf_filter(nsim, alpha, weights, indices);
+
+
   arma::mat at(m, n + 1);
   arma::mat att(m, n + 1);
   arma::cube Pt(m, m, n + 1);
   arma::cube Ptt(m, m, n + 1);
   filter_summary(alpha, at, att, Pt, Ptt, weights);
-  
+
   arma::inplace_trans(att);
   return Rcpp::List::create(
-    Rcpp::Named("att") = att, 
-    Rcpp::Named("Ptt") = Ptt, 
+    Rcpp::Named("att") = att,
+    Rcpp::Named("Ptt") = Ptt,
     Rcpp::Named("weights") = weights,
     Rcpp::Named("logLik") = loglik, Rcpp::Named("alpha") = alpha);
 }
 
 // [[Rcpp::export]]
-Rcpp::List ekpf_smoother(const arma::mat& y, SEXP Z, SEXP H, 
-  SEXP T, SEXP R, SEXP Zg, SEXP Tg, SEXP a1, SEXP P1, 
-  const arma::vec& theta, SEXP log_prior_pdf, const arma::vec& known_params, 
-  const arma::mat& known_tv_params, const unsigned int n_states, 
+Rcpp::List ekpf_smoother(const arma::mat& y, SEXP Z, SEXP H,
+  SEXP T, SEXP R, SEXP Zg, SEXP Tg, SEXP a1, SEXP P1,
+  const arma::vec& theta, SEXP log_prior_pdf, const arma::vec& known_params,
+  const arma::mat& known_tv_params, const unsigned int n_states,
   const unsigned int n_etas,  const arma::uvec& time_varying,
-  const unsigned int nsim_states, 
-  const unsigned int seed) {
-  
+  const unsigned int nsim, const unsigned int seed,
+  const Rcpp::Function update_fn, const Rcpp::Function prior_fn) {
+
   Rcpp::XPtr<nvec_fnPtr> xpfun_Z(Z);
   Rcpp::XPtr<nmat_fnPtr> xpfun_H(H);
   Rcpp::XPtr<nvec_fnPtr> xpfun_T(T);
@@ -68,30 +68,30 @@ Rcpp::List ekpf_smoother(const arma::mat& y, SEXP Z, SEXP H,
   Rcpp::XPtr<a1_fnPtr> xpfun_a1(a1);
   Rcpp::XPtr<P1_fnPtr> xpfun_P1(P1);
   Rcpp::XPtr<prior_fnPtr> xpfun_prior(log_prior_pdf);
-  
-  nlg_ssm model(y, *xpfun_Z, *xpfun_H, *xpfun_T, *xpfun_R, *xpfun_Zg, *xpfun_Tg, 
+
+  ssm_nlg model(y, *xpfun_Z, *xpfun_H, *xpfun_T, *xpfun_R, *xpfun_Zg, *xpfun_Tg,
     *xpfun_a1, *xpfun_P1,  theta, *xpfun_prior, known_params, known_tv_params, n_states, n_etas,
-    time_varying, seed);
-  
+    time_varying, update_fn, prior_fn, seed);
+
   unsigned int m = model.m;
   unsigned n = model.n;
-  
-  arma::cube alpha(m, n + 1, nsim_states);
-  arma::mat weights(nsim_states, n + 1);
-  arma::umat indices(nsim_states, n);
-  double loglik = model.ekf_filter(nsim_states, alpha, weights, indices);
 
-  
-  arma::mat alphahat(model.m, model.n);
-  arma::cube Vt(model.m, model.m, model.n);
-  
+  arma::cube alpha(m, n + 1, nsim);
+  arma::mat weights(nsim, n + 1);
+  arma::umat indices(nsim, n);
+  double loglik = model.ekf_filter(nsim, alpha, weights, indices);
+
+
+  arma::mat alphahat(model.m, model.n + 1);
+  arma::cube Vt(model.m, model.m, model.n + 1);
+
   filter_smoother(alpha, indices);
   weighted_summary(alpha, alphahat, Vt, weights.col(model.n));
- 
+
   arma::inplace_trans(alphahat);
-  
+
   return Rcpp::List::create(
-    Rcpp::Named("alphahat") = alphahat, Rcpp::Named("Vt") = Vt, 
+    Rcpp::Named("alphahat") = alphahat, Rcpp::Named("Vt") = Vt,
     Rcpp::Named("weights") = weights,
     Rcpp::Named("logLik") = loglik, Rcpp::Named("alpha") = alpha);
   }
