@@ -988,17 +988,16 @@ double ssm_nlg::psi_filter(const unsigned int nsim, arma::cube& alpha,
   arma::uvec na_y = arma::find_nonfinite(y.col(0));
   if (na_y.n_elem < p) { 
     weights.col(0) = 
-      arma::exp(log_weights(0, alpha, arma::mat(m, nsim, arma::fill::zeros)) - scales(0));
-    // double max_weight = weights.col(0).max();
-    // weights.col(0) = arma::exp(weights.col(0) - max_weight);
+      log_weights(0, alpha, arma::mat(m, nsim, arma::fill::zeros)) - scales(0);
+    double max_weight = weights.col(0).max();
+    weights.col(0) = arma::exp(weights.col(0) - max_weight);
     double sum_weights = arma::accu(weights.col(0));
     if(sum_weights > 0.0){
       normalized_weights = weights.col(0) / sum_weights;
     } else {
       return -std::numeric_limits<double>::infinity();
     }
-    //loglik = max_weight + approx_loglik + std::log(sum_weights / nsim);
-    loglik = approx_loglik + std::log(sum_weights / nsim);
+    loglik = max_weight + approx_loglik + std::log(sum_weights / nsim);
   } else {
     weights.col(0).ones();
     normalized_weights.fill(1.0 / nsim);
@@ -1027,16 +1026,16 @@ double ssm_nlg::psi_filter(const unsigned int nsim, arma::cube& alpha,
     }
     
     if (t < (n - 1) && arma::uvec(arma::find_nonfinite(y.col(t + 1))).n_elem < p) {
-      weights.col(t + 1) = exp(log_weights(t + 1, alpha, alphatmp)  - scales(t+1));
-      // double max_weight = weights.col(t + 1).max();
-      // weights.col(t+1) = arma::exp(weights.col(t+1) - max_weight);
+      weights.col(t + 1) = log_weights(t + 1, alpha, alphatmp)  - scales(t + 1);
+      double max_weight = weights.col(t + 1).max();
+      weights.col(t + 1) = arma::exp(weights.col(t + 1) - max_weight);
       double sum_weights = arma::accu(weights.col(t + 1));
       if(sum_weights > 0.0){
         normalized_weights = weights.col(t + 1) / sum_weights;
       } else {
         return -std::numeric_limits<double>::infinity();
       }
-      loglik += std::log(sum_weights / nsim); //max_weight + 
+      loglik += max_weight + std::log(sum_weights / nsim); 
     } else {
       weights.col(t + 1).ones();
       normalized_weights.fill(1.0 / nsim);
